Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(490)

Unified Diff: webrtc/p2p/base/packettransportinternal.h

Issue 2679103006: Rename "PacketTransportInterface" to "PacketTransportInternal". (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/p2p/base/packettransportinterface.h ('k') | webrtc/p2p/base/transportcontroller.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/p2p/base/packettransportinternal.h
diff --git a/webrtc/p2p/base/packettransportinterface.h b/webrtc/p2p/base/packettransportinternal.h
similarity index 79%
copy from webrtc/p2p/base/packettransportinterface.h
copy to webrtc/p2p/base/packettransportinternal.h
index 04130ef040b811cb726da637addad134ed587c5f..5789c62eeacaec610afc088475336e37c1c4efad 100644
--- a/webrtc/p2p/base/packettransportinterface.h
+++ b/webrtc/p2p/base/packettransportinternal.h
@@ -8,8 +8,8 @@
* be found in the AUTHORS file in the root of the source tree.
*/
-#ifndef WEBRTC_P2P_BASE_PACKETTRANSPORTINTERFACE_H_
-#define WEBRTC_P2P_BASE_PACKETTRANSPORTINTERFACE_H_
+#ifndef WEBRTC_P2P_BASE_PACKETTRANSPORTINTERNAL_H_
+#define WEBRTC_P2P_BASE_PACKETTRANSPORTINTERNAL_H_
#include <string>
#include <vector>
@@ -28,9 +28,9 @@ struct PacketOptions;
struct PacketTime;
struct SentPacket;
-class PacketTransportInterface : public sigslot::has_slots<> {
+class PacketTransportInternal : public sigslot::has_slots<> {
public:
- virtual ~PacketTransportInterface() {}
+ virtual ~PacketTransportInternal() {}
// Identify the object for logging and debug purpose.
virtual std::string debug_name() const = 0;
@@ -59,7 +59,7 @@ class PacketTransportInterface : public sigslot::has_slots<> {
// supported by all transport types.
virtual int SetOption(rtc::Socket::Option opt, int value) = 0;
// TODO(pthatcher): Once Chrome's MockPacketTransportInterface implements
// this, remove the default implementation.
virtual bool GetOption(rtc::Socket::Option opt, int* value) { return false; }
@@ -67,20 +67,20 @@ class PacketTransportInterface : public sigslot::has_slots<> {
virtual int GetError() = 0;
// Emitted when the writable state, represented by |writable()|, changes.
- sigslot::signal1<PacketTransportInterface*> SignalWritableState;
+ sigslot::signal1<PacketTransportInternal*> SignalWritableState;
- // Emitted when the PacketTransportInterface is ready to send packets. "Ready
+ // Emitted when the PacketTransportInternal is ready to send packets. "Ready
// to send" is more sensitive than the writable state; a transport may be
// writable, but temporarily not able to send packets. For example, the
// underlying transport's socket buffer may be full, as indicated by
// SendPacket's return code and/or GetError.
- sigslot::signal1<PacketTransportInterface*> SignalReadyToSend;
+ sigslot::signal1<PacketTransportInternal*> SignalReadyToSend;
// Emitted when receiving state changes to true.
- sigslot::signal1<PacketTransportInterface*> SignalReceivingState;
+ sigslot::signal1<PacketTransportInternal*> SignalReceivingState;
// Signalled each time a packet is received on this channel.
- sigslot::signal5<PacketTransportInterface*,
+ sigslot::signal5<PacketTransportInternal*,
const char*,
size_t,
const rtc::PacketTime&,
@@ -88,10 +88,10 @@ class PacketTransportInterface : public sigslot::has_slots<> {
SignalReadPacket;
// Signalled each time a packet is sent on this channel.
- sigslot::signal2<PacketTransportInterface*, const rtc::SentPacket&>
+ sigslot::signal2<PacketTransportInternal*, const rtc::SentPacket&>
SignalSentPacket;
};
} // namespace rtc
-#endif // WEBRTC_P2P_BASE_PACKETTRANSPORTINTERFACE_H_
+#endif // WEBRTC_P2P_BASE_PACKETTRANSPORTINTERNAL_H_
« no previous file with comments | « webrtc/p2p/base/packettransportinterface.h ('k') | webrtc/p2p/base/transportcontroller.h » ('j') | no next file with comments »

Powered by Google App Engine
@@ -59,7 +59,7 @@ class PacketTransportInterface : public sigslot::has_slots<> {
// supported by all transport types.
virtual int SetOption(rtc::Socket::Option opt, int value) = 0;
- // TODO(pthatcher): Once Chrome's MockPacketTransportInterface implements
+ // TODO(pthatcher): Once Chrome's MockPacketTransportInternal implements
// this, remove the default implementation.
virtual bool GetOption(rtc::Socket::Option opt, int* value) { return false; }
This is Rietveld 408576698